import { __extends, __awaiter, __generator, __decorate, __metadata, __read } from 'tslib';
import { HostBinding, Component, NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms';
import { setTheme } from 'ngx-bootstrap/utils';
import { BaseUIComponent, propDescription, ContainerProperties, LabeledComponent, LabelProperties, PropertyCategories, JSONUtils, StyleProperties, getItemByIndex, BindingProperties, CoreService, CoreModule } from '@ngx-dynamic-components/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { NgSelectModule } from '@ng-select/ng-select';
import { TabsModule } from 'ngx-bootstrap/tabs';

var packageName = 'bootstrap';

var ContainerComponent = /** @class */ (function (_super) {
    __extends(ContainerComponent, _super);
    function ContainerComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.isContainer = true;
        _this.isFluidContainer = false;
        _this.height = 'auto';
        _this.dropContainer = true;
        return _this;
    }
    ContainerComponent.prototype.ngOnInit = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.ngOnInit.call(this)];
                    case 1:
                        _a.sent();
                        if (this.properties.fullWidth) {
                            this.isFluidContainer = true;
                            this.isContainer = false;
                        }
                        if (this.properties.height) {
                            this.height = this.properties.height;
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    __decorate([
        HostBinding('class.container'),
        __metadata("design:type", Object)
    ], ContainerComponent.prototype, "isContainer", void 0);
    __decorate([
        HostBinding('class.container-fluid'),
        __metadata("design:type", Object)
    ], ContainerComponent.prototype, "isFluidContainer", void 0);
    __decorate([
        HostBinding('style.height'),
        __metadata("design:type", Object)
    ], ContainerComponent.prototype, "height", void 0);
    __decorate([
        HostBinding('attr.drop-container'),
        __metadata("design:type", Object)
    ], ContainerComponent.prototype, "dropContainer", void 0);
    ContainerComponent = __decorate([
        Component({
            selector: 'dc-container',
            template: "\n    <dc-container-row *ngFor=\"let item of uiModel.children\" [ngStyle]=\"getStyles(item.itemProperties)\"\n      (changedDataModel)=\"changedDataModel.emit($event)\"\n      [uiModel]='item'\n      [dataModel]='dataModel'\n      [interpreter]='interpreter'\n      [scripts]='scripts'\n    ></dc-container-row>\n  ",
            styles: ["\n    :host {\n      display: block;\n    }\n  "]
        })
    ], ContainerComponent);
    return ContainerComponent;
}(BaseUIComponent));
var BSContainerProperties = /** @class */ (function (_super) {
    __extends(BSContainerProperties, _super);
    function BSContainerProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Is full width container, default false',
            example: 'true',
        }),
        __metadata("design:type", Boolean)
    ], BSContainerProperties.prototype, "fullWidth", void 0);
    return BSContainerProperties;
}(ContainerProperties));
var example = {
    title: 'Bootstrap container example',
    uiModel: {
        type: 'bootstrap:container',
        containerProperties: {},
        itemProperties: {},
        children: [{
                type: 'bootstrap:bs-row',
                children: [{
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-1',
                            placeholder: 'Name first section',
                            dataModelPath: '$.first'
                        }
                    }, {
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-2',
                            placeholder: 'Name second section',
                            dataModelPath: '$.second'
                        }
                    }]
            }, {
                type: 'bootstrap:bs-row',
                children: [{
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-11',
                            placeholder: 'Name third section',
                            dataModelPath: '$.third'
                        }
                    }, {
                        type: 'bootstrap:text-input',
                        containerProperties: {},
                        itemProperties: {
                            label: 'Input-22',
                            placeholder: 'Name fourth section',
                            dataModelPath: '$.forth'
                        }
                    }]
            }]
    },
    dataModel: {}
};
var containerDescriptor = {
    name: 'container',
    label: 'Container',
    packageName: packageName,
    category: "Containers" /* Containers */,
    description: 'Bootstrap container',
    itemProperties: BSContainerProperties,
    component: ContainerComponent,
    example: example,
    defaultModel: {
        type: 'bootstrap:container',
        containerProperties: {
            height: '100%',
            width: '100%'
        },
        itemProperties: {},
        children: []
    }
};

var ContainerRowComponent = /** @class */ (function (_super) {
    __extends(ContainerRowComponent, _super);
    function ContainerRowComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.isRow = true;
        _this.isColumn = false;
        _this.dropContainer = true;
        _this.display = 'flex';
        _this.height = 'auto';
        return _this;
    }
    ContainerRowComponent.prototype.ngOnInit = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, _super.prototype.ngOnInit.call(this)];
                    case 1:
                        _a.sent();
                        this.isColumn = this.properties && this.properties.direction === 'column';
                        if (this.uiModel.containerProperties && this.uiModel.containerProperties.height) {
                            this.height = this.uiModel.containerProperties.height;
                        }
                        return [2 /*return*/];
                }
            });
        });
    };
    __decorate([
        HostBinding('class.row'),
        __metadata("design:type", Object)
    ], ContainerRowComponent.prototype, "isRow", void 0);
    __decorate([
        HostBinding('class.flex-column'),
        __metadata("design:type", Object)
    ], ContainerRowComponent.prototype, "isColumn", void 0);
    __decorate([
        HostBinding('attr.drop-container'),
        __metadata("design:type", Object)
    ], ContainerRowComponent.prototype, "dropContainer", void 0);
    __decorate([
        HostBinding('style.display'),
        __metadata("design:type", Object)
    ], ContainerRowComponent.prototype, "display", void 0);
    __decorate([
        HostBinding('style.height'),
        __metadata("design:type", Object)
    ], ContainerRowComponent.prototype, "height", void 0);
    ContainerRowComponent = __decorate([
        Component({
            selector: 'dc-container-row',
            template: "\n    <div *ngFor=\"let item of uiModel.children\" class=\"col\" [ngStyle]=\"getStyles(item.containerProperties)\"\n      [ngClass]=\"item.containerProperties?.bsClasses\">\n      <dc-ui-selector\n          (changedDataModel)=\"changedDataModel.emit($event)\"\n          [uiModel]='item'\n          [dataModel]='dataModel'\n          [interpreter]='interpreter'\n          [scripts]='scripts'\n      ></dc-ui-selector>\n    </div>\n  "
        })
    ], ContainerRowComponent);
    return ContainerRowComponent;
}(BaseUIComponent));
var BSContainerRowProperties = /** @class */ (function (_super) {
    __extends(BSContainerRowProperties, _super);
    function BSContainerRowProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Bootstrap row child classes',
            example: 'col-9'
        }),
        __metadata("design:type", Array)
    ], BSContainerRowProperties.prototype, "bsClasses", void 0);
    __decorate([
        propDescription({
            description: 'Flex direction',
            example: 'column'
        }),
        __metadata("design:type", String)
    ], BSContainerRowProperties.prototype, "direction", void 0);
    return BSContainerRowProperties;
}(ContainerProperties));
var example$1 = {
    title: 'Bootstrap container row example',
    uiModel: {
        type: 'bootstrap:bs-row',
        containerProperties: {},
        itemProperties: {
            width: '50%',
            padding: '10px'
        },
        children: [{
                type: 'bootstrap:text-input',
                containerProperties: {},
                itemProperties: {
                    label: 'Input-1',
                    placeholder: 'Name first section',
                    dataModelPath: '$.first'
                }
            }, {
                type: 'bootstrap:text-input',
                containerProperties: {},
                itemProperties: {
                    label: 'Input2',
                    placeholder: 'Name second section',
                    dataModelPath: '$.second'
                }
            }]
    },
    dataModel: {}
};
var containerRowDescriptor = {
    name: 'bs-row',
    label: 'Row',
    packageName: 'bootstrap',
    category: "Containers" /* Containers */,
    description: 'Bootstrap row container',
    itemProperties: BSContainerRowProperties,
    component: ContainerRowComponent,
    example: example$1,
    defaultModel: {
        type: 'bootstrap:bs-row',
        containerProperties: {},
        itemProperties: {
            height: '100px',
            width: '100%'
        },
        children: []
    }
};

var InputUIComponent = /** @class */ (function (_super) {
    __extends(InputUIComponent, _super);
    function InputUIComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(InputUIComponent.prototype, "cssClasses", {
        get: function () {
            return {
                invisible: this.properties.visible === false,
                required: this.properties.required
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InputUIComponent.prototype, "inputStyles", {
        get: function () {
            return this.getStyles(this.uiModel.itemProperties, ['background', 'color']);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InputUIComponent.prototype, "wrapperStyles", {
        get: function () {
            if (this.properties.inputHeight) {
                return {
                    height: this.properties.inputHeight
                };
            }
            return null;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(InputUIComponent.prototype, "name", {
        get: function () {
            return this.properties.dataModelPath.replace(/[^A-Z]+/gi, '');
        },
        enumerable: true,
        configurable: true
    });
    InputUIComponent = __decorate([
        Component({
            selector: 'dc-input-ui',
            template: "\n  <div class=\"form-group align-items-baseline\" [fxLayout]=\"layout\" [ngClass]=\"cssClasses\" [ngStyle]=\"itemStyles\">\n    <label class=\"mr-1 {{properties.labelPosition}}\" [for]=\"id\" *ngIf=\"hasLabel\"\n      [fxFlex]=\"layout === 'row' ? properties.labelWidth : false\">{{properties.label}}</label>\n    <div class=\"w-100 flex-column\" [ngStyle]=\"wrapperStyles\">\n      <input [attr.id]=\"id\" #inputField=\"ngModel\" [type]=\"properties.type\" class=\"form-control\" [ngStyle]=\"inputStyles\"\n        [fxFlex]=\"properties.inputWidth\"\n        [placeholder]=\"properties.placeholder\"\n        [disabled]=\"properties.enabled === false\"\n        [required]=\"properties.required\"\n        [minlength]=\"properties.minlength\"\n        [maxlength]=\"properties.maxlength\"\n        [email]=\"properties.type === 'email'\"\n        [pattern]=\"properties.pattern\"\n        (input)=\"changedDataModel.emit(this.dataModel)\"\n        [attr.name]=\"name\"\n        [(ngModel)]=\"componentDataModel\">\n      <div *ngIf=\"inputField.invalid && (inputField.dirty || inputField.touched)\" class=\"alert alert-danger py-0 px-1 m-0\">\n        <div *ngIf=\"inputField.errors.required\">Field is required.</div>\n        <div *ngIf=\"inputField.errors.minlength\">Min length {{properties.minlength}} characters.</div>\n        <div *ngIf=\"inputField.errors.maxlength\">Max length {{properties.minlength}} characters.</div>\n        <div *ngIf=\"inputField.errors.email\">Email is invalid.</div>\n        <div *ngIf=\"inputField.errors.pattern\">Field should match required pattern.</div>\n      </div>\n    </div>\n  </div>\n  ",
            styles: ["label.bottom,label.right{-webkit-box-ordinal-group:2;order:1}", "\n    :host {\n      display: inline-block;\n    }\n\n    .required label:after {\n      content: '*';\n    }\n  "]
        })
    ], InputUIComponent);
    return InputUIComponent;
}(LabeledComponent));
var InputProperties = /** @class */ (function (_super) {
    __extends(InputProperties, _super);
    function InputProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Text shown when field is empty',
            example: 'Type your name',
        }),
        __metadata("design:type", String)
    ], InputProperties.prototype, "placeholder", void 0);
    __decorate([
        propDescription({
            description: 'Input type',
            example: 'text',
        }),
        __metadata("design:type", String)
    ], InputProperties.prototype, "type", void 0);
    __decorate([
        propDescription({
            description: 'Is enabled',
            example: 'true',
        }),
        __metadata("design:type", Boolean)
    ], InputProperties.prototype, "enabled", void 0);
    __decorate([
        propDescription({
            description: 'Is visible',
            example: 'true',
        }),
        __metadata("design:type", Boolean)
    ], InputProperties.prototype, "visible", void 0);
    __decorate([
        propDescription({
            description: 'Input width',
            example: '200px',
        }),
        __metadata("design:type", String)
    ], InputProperties.prototype, "inputWidth", void 0);
    __decorate([
        propDescription({
            description: 'Is field required',
            example: 'true'
        }),
        __metadata("design:type", String)
    ], InputProperties.prototype, "inputHeight", void 0);
    __decorate([
        propDescription({
            description: 'Is field required',
            example: 'true'
        }),
        __metadata("design:type", Boolean)
    ], InputProperties.prototype, "required", void 0);
    __decorate([
        propDescription({
            description: 'Min field value length',
            example: '5'
        }),
        __metadata("design:type", Number)
    ], InputProperties.prototype, "minlength", void 0);
    __decorate([
        propDescription({
            description: 'Max field value length',
            example: '10'
        }),
        __metadata("design:type", Number)
    ], InputProperties.prototype, "maxlength", void 0);
    __decorate([
        propDescription({
            description: 'RegExp pattern',
            example: '[a-zA-Z ]*'
        }),
        __metadata("design:type", String)
    ], InputProperties.prototype, "pattern", void 0);
    return InputProperties;
}(LabelProperties));
var example$2 = {
    title: 'Text input example',
    uiModel: {
        type: packageName + ":text-input",
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            placeholder: 'Enter your name',
            dataModelPath: '$.name'
        }
    },
    dataModel: {}
};
var inputDescriptor = {
    name: 'text-input',
    label: 'Input field',
    packageName: packageName,
    category: "Basic" /* Basic */,
    description: 'Input component',
    itemProperties: InputProperties,
    component: InputUIComponent,
    example: example$2,
    defaultModel: {
        type: packageName + ":text-input",
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            placeholder: 'Enter your text',
            dataModelPath: '$.path',
            visible: true,
            enabled: true,
            inputWidth: '100%',
            labelWidth: '80px',
            width: '200px',
            margin: '0',
            type: 'text',
            labelPosition: ''
        }
    },
    propertiesDescriptor: [
        ['type', { name: 'type', label: 'Data Type', category: PropertyCategories.Main,
                combo: [['text', 'number', 'email', 'file', 'url', 'date', 'time', 'datetime-local']]
            }],
        ['inputWidth', { name: 'inputWidth', label: 'Input Width', category: PropertyCategories.Layout }],
        ['inputHeight', { name: 'inputHeight', label: 'Input Height', category: PropertyCategories.Layout }],
        ['enabled', { name: 'enabled', label: 'Enabled', category: PropertyCategories.Main,
                combo: [[{ label: 'Enable', value: true }, { label: 'Disable', value: false }]]
            }],
        ['visible', { name: 'visible', label: 'Visible', category: PropertyCategories.Main,
                combo: [[{ label: 'Visible', value: true }, { label: 'Hidden', value: false }]]
            }]
    ]
};

var SelectUIComponent = /** @class */ (function (_super) {
    __extends(SelectUIComponent, _super);
    function SelectUIComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.options = [];
        return _this;
    }
    SelectUIComponent.prototype.onSelect = function () {
        this.changedDataModel.emit(this.dataModel);
        this.triggerAction('_selectionChanged');
    };
    Object.defineProperty(SelectUIComponent.prototype, "selectStyles", {
        get: function () {
            if (this.properties.selectHeight) {
                return {
                    height: this.properties.selectHeight
                };
            }
            return null;
        },
        enumerable: true,
        configurable: true
    });
    SelectUIComponent.prototype.ngDoCheck = function () {
        if (this.dataModel) {
            var options = this.properties.options;
            if (Array.isArray(options)) {
                this.options = options;
            }
            else if (typeof options === 'string') {
                var val = JSONUtils.find(this.dataModel, options);
                if (val !== this.options) {
                    this.options = val;
                }
            }
        }
    };
    Object.defineProperty(SelectUIComponent.prototype, "disabled", {
        get: function () {
            var options = this.properties.options;
            return options && options.length ? null : 'disabled';
        },
        enumerable: true,
        configurable: true
    });
    SelectUIComponent = __decorate([
        Component({
            selector: 'dc-select-ui',
            template: "\n    <div class=\"form-group mb-0\" [fxLayout]=\"layout\" [ngStyle]=\"itemStyles\">\n      <label selected *ngIf=\"hasLabel\" [for]=\"id\" [class]=\"properties.labelPosition\"\n      [fxFlex]=\"layout === 'row' ? properties.labelWidth : false\">{{properties.label}}</label>\n      <ng-select [items]=\"options\" (change)=\"onSelect()\" [ngStyle]=\"selectStyles\"\n      [(ngModel)]=\"componentDataModel\" bindValue=\"value\" [attr.disabled]=\"disabled\"></ng-select>\n    </div>",
            styles: ["label.bottom,label.right{-webkit-box-ordinal-group:2;order:1}", "\n    :host ::ng-deep .ng-select.ng-select-single .ng-select-container {\n      height: inherit;\n      min-height: 30px;\n    }\n  "]
        })
    ], SelectUIComponent);
    return SelectUIComponent;
}(LabeledComponent));
var SelectProperties = /** @class */ (function (_super) {
    __extends(SelectProperties, _super);
    function SelectProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Select options.',
            example: '[{label: "One", value: 1}]',
        }),
        __metadata("design:type", Array)
    ], SelectProperties.prototype, "options", void 0);
    __decorate([
        propDescription({
            description: 'Select height.',
            example: '30px',
        }),
        __metadata("design:type", String)
    ], SelectProperties.prototype, "selectHeight", void 0);
    return SelectProperties;
}(LabelProperties));
var example$3 = {
    uiModel: {
        type: packageName + ":select",
        containerProperties: {},
        id: 'stateSelection',
        itemProperties: {
            options: [
                { label: 'United Kingdom', value: 'uk' },
                { label: 'Ukraine', value: 'ua' }
            ],
            label: 'Country',
            dataModelPath: '$.country'
        }
    },
    dataModel: {},
    title: 'Basic select example'
};
var selectDescriptor = {
    name: 'select',
    label: 'UI Select Input',
    packageName: packageName,
    category: "Basic" /* Basic */,
    description: 'Select component',
    itemProperties: SelectProperties,
    component: SelectUIComponent,
    example: example$3,
    defaultModel: {
        type: packageName + ":select",
        containerProperties: {},
        itemProperties: {
            options: [
                { label: 'First option', value: '1' },
                { label: 'Second option', value: '2' }
            ],
            width: '200px',
            label: 'Select option',
            dataModelPath: '$.option'
        }
    },
    propertiesDescriptor: [
        ['selectHeight', { name: 'selectHeight', label: 'Select Height', category: PropertyCategories.Layout }],
    ]
};

var CheckboxUIComponent = /** @class */ (function (_super) {
    __extends(CheckboxUIComponent, _super);
    function CheckboxUIComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(CheckboxUIComponent.prototype, "align", {
        get: function () {
            return this.layout === 'row' ? 'start center' : 'center start';
        },
        enumerable: true,
        configurable: true
    });
    CheckboxUIComponent = __decorate([
        Component({
            selector: 'dc-checkbox-ui',
            template: "\n    <div [fxLayout]=\"layout\" [fxLayoutAlign]=\"align\" [ngStyle]=\"itemStyles\">\n      <label *ngIf=\"hasLabel\" [for]=\"id\"  class=\"{{properties.labelPosition}} my-0\"\n      [fxFlex]=\"layout === 'row' ? properties.labelWidth : false\">{{properties.label}}</label>\n      <input type=\"checkbox\" class=\"mx-0\" [attr.id]=\"id\"\n        (change)=\"changedDataModel.emit(this.dataModel)\"\n        [(ngModel)]=\"componentDataModel\">\n    </div>\n  ",
            styles: ["label.bottom,label.right{-webkit-box-ordinal-group:2;order:1}", "\n    label.bottom, label.top {\n      margin: 0;\n    }\n\n    label.right {\n      margin-left: 5px;\n    }\n\n    label.left {\n      margin-right: 5px;\n    }\n  "]
        })
    ], CheckboxUIComponent);
    return CheckboxUIComponent;
}(LabeledComponent));
var CheckboxProperties = /** @class */ (function (_super) {
    __extends(CheckboxProperties, _super);
    function CheckboxProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return CheckboxProperties;
}(LabelProperties));
var example$4 = {
    title: 'Checkbox example',
    uiModel: {
        type: packageName + ":checkbox",
        containerProperties: {},
        itemProperties: {
            label: 'Accept conditions',
            dataModelPath: '$.accept',
            labelPosition: 'right'
        }
    },
    dataModel: {}
};
var checkboxDescriptor = {
    name: 'checkbox',
    packageName: packageName,
    label: 'Checkbox',
    category: "Basic" /* Basic */,
    description: 'Checkbox component',
    itemProperties: CheckboxProperties,
    component: CheckboxUIComponent,
    example: example$4,
    defaultModel: {
        type: packageName + ":checkbox",
        containerProperties: {},
        itemProperties: {
            label: 'Accept conditions',
            width: '200px',
            dataModelPath: '$.accept',
            labelPosition: 'left'
        }
    }
};

var RadioGroupUIComponent = /** @class */ (function (_super) {
    __extends(RadioGroupUIComponent, _super);
    function RadioGroupUIComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(RadioGroupUIComponent.prototype, "align", {
        get: function () {
            return this.layout === 'row' ? 'start center' : 'center start';
        },
        enumerable: true,
        configurable: true
    });
    RadioGroupUIComponent.prototype.onChange = function (option) {
        this.componentDataModel = option.value;
        this.changedDataModel.emit(this.dataModel);
    };
    RadioGroupUIComponent = __decorate([
        Component({
            selector: 'dc-radio-group-ui',
            template: "\n    <div class=\"form-check\" *ngFor=\"let option of properties.options\"\n      [fxLayout]=\"layout\" [fxLayoutAlign]=\"align\" [ngStyle]=\"itemStyles\">\n      <label class=\"mb-0 {{properties.labelPosition}}\" [for]=\"id\" *ngIf=\"hasLabel\"\n        [fxFlex]=\"layout === 'row' ? properties.labelWidth : false\">{{option.label}}</label>\n      <input type=\"radio\"\n        (change)=\"onChange(option)\"\n        [name]=\"properties.dataModelPath\" [value]=\"option.value\">\n    </div>\n  ",
            styles: ["label.bottom,label.right{-webkit-box-ordinal-group:2;order:1}"]
        })
    ], RadioGroupUIComponent);
    return RadioGroupUIComponent;
}(LabeledComponent));
var RadioGroupProperties = /** @class */ (function (_super) {
    __extends(RadioGroupProperties, _super);
    function RadioGroupProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Radio group options',
            example: '[{label: "One", value: 1}]',
        }),
        __metadata("design:type", Array)
    ], RadioGroupProperties.prototype, "options", void 0);
    return RadioGroupProperties;
}(LabelProperties));
var example$5 = {
    title: 'Radio group example',
    uiModel: {
        type: packageName + ":radio-group",
        containerProperties: {},
        itemProperties: {
            label: 'Select color',
            dataModelPath: '$.color',
            options: [{ label: 'White', value: 'white' }, { label: 'Black', value: 'black' }],
        }
    },
    dataModel: {}
};
var radioGroupDescriptor = {
    name: 'radio-group',
    label: 'Single choice boxes',
    packageName: packageName,
    category: "Basic" /* Basic */,
    description: 'Radio group component',
    itemProperties: RadioGroupProperties,
    component: RadioGroupUIComponent,
    example: example$5,
    defaultModel: {
        type: packageName + ":radio-group",
        containerProperties: {},
        itemProperties: {
            label: 'Select option',
            dataModelPath: '$.radioGroup',
            options: [{ label: 'Option 1', value: '1' }, { label: 'Option 2', value: 'black' }],
        }
    }
};

var TextareaUIComponent = /** @class */ (function (_super) {
    __extends(TextareaUIComponent, _super);
    function TextareaUIComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TextareaUIComponent = __decorate([
        Component({
            selector: 'dc-textarea-ui',
            template: "\n    <div class=\"form-group\" [ngStyle]=\"itemStyles\"  [fxLayout]=\"layout\">\n      <label *ngIf=\"hasLabel\" [class]=\"properties.labelPosition\" [for]=\"id\"\n        [fxFlex]=\"layout === 'row' ? properties.labelWidth : false\">{{properties.label}}</label>\n      <div class=\"w-100 flex-column\">\n        <textarea #txtAreaField=\"ngModel\" [attr.id]=\"id\" class=\"form-control\"\n          [rows]=\"properties.rows\"\n          [placeholder]=\"properties.placeholder\"\n          [ngStyle]=\"itemStyles\"\n          [required]=\"properties.required\"\n          [minlength]=\"properties.minlength\"\n          [maxlength]=\"properties.maxlength\"\n          (input)=\"changedDataModel.emit(this.dataModel)\"\n          [(ngModel)]=\"componentDataModel\"></textarea>\n        <div *ngIf=\"txtAreaField.invalid && (txtAreaField.dirty || txtAreaField.touched)\" class=\"alert alert-danger py-0 px-1 m-0\">\n          <div *ngIf=\"txtAreaField.errors.required\">Field is required.</div>\n          <div *ngIf=\"txtAreaField.errors.minlength\">Min length {{properties.minlength}} characters.</div>\n          <div *ngIf=\"txtAreaField.errors.maxlength\">Max length {{properties.minlength}} characters.</div>\n        </div>\n      </div>\n    </div>\n  ",
            styles: ["label.bottom,label.right{-webkit-box-ordinal-group:2;order:1}"]
        })
    ], TextareaUIComponent);
    return TextareaUIComponent;
}(LabeledComponent));
var TextareaProperties = /** @class */ (function (_super) {
    __extends(TextareaProperties, _super);
    function TextareaProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Number of rows in textarea',
            example: '5',
        }),
        __metadata("design:type", Number)
    ], TextareaProperties.prototype, "rows", void 0);
    __decorate([
        propDescription({
            description: 'Text shown when field is empty',
            example: 'Type about yourself',
        }),
        __metadata("design:type", String)
    ], TextareaProperties.prototype, "placeholder", void 0);
    __decorate([
        propDescription({
            description: 'Is field required',
            example: 'true'
        }),
        __metadata("design:type", Boolean)
    ], TextareaProperties.prototype, "required", void 0);
    __decorate([
        propDescription({
            description: 'Min field value length',
            example: '5'
        }),
        __metadata("design:type", Number)
    ], TextareaProperties.prototype, "minlength", void 0);
    __decorate([
        propDescription({
            description: 'Max field value length',
            example: '10'
        }),
        __metadata("design:type", Number)
    ], TextareaProperties.prototype, "maxlength", void 0);
    return TextareaProperties;
}(LabelProperties));
var example$6 = {
    title: 'Text area example',
    uiModel: {
        type: packageName + ":textarea",
        containerProperties: {},
        itemProperties: {
            rows: 10,
            placeholder: 'Type information about yourself',
            dataModelPath: '$.info'
        }
    },
    dataModel: {}
};
var textareaDescriptor = {
    name: 'textarea',
    label: 'Text Area',
    packageName: packageName,
    category: "Basic" /* Basic */,
    description: 'Text area component',
    itemProperties: TextareaProperties,
    component: TextareaUIComponent,
    example: example$6,
    defaultModel: {
        type: packageName + ":textarea",
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            rows: 5,
            placeholder: 'Placeholder text',
            dataModelPath: '$.textarea'
        }
    }
};

var ButtonUIComponent = /** @class */ (function (_super) {
    __extends(ButtonUIComponent, _super);
    function ButtonUIComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ButtonUIComponent.prototype.onClick = function () {
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        if (!this.properties.clickActionKey) return [3 /*break*/, 4];
                        this.evaluate.emit(true);
                        _a.label = 1;
                    case 1:
                        _a.trys.push([1, , 3, 4]);
                        return [4 /*yield*/, this.interpreter.evaluate(this.scripts, { dataModel: this.dataModel, uiModel: this.uiModel }, this.properties.clickActionKey)];
                    case 2:
                        _a.sent();
                        this.changedDataModel.emit(this.dataModel);
                        return [3 /*break*/, 4];
                    case 3:
                        this.evaluate.emit(false);
                        return [7 /*endfinally*/];
                    case 4: return [2 /*return*/];
                }
            });
        });
    };
    Object.defineProperty(ButtonUIComponent.prototype, "btnClass", {
        get: function () {
            var _a;
            return _a = {},
                _a["btn " + this.properties.btnClass] = this.properties.btnClass,
                _a;
        },
        enumerable: true,
        configurable: true
    });
    ButtonUIComponent = __decorate([
        Component({
            selector: 'dc-button-ui',
            template: "\n    <a *ngIf=\"properties.type == 'link' else btn\"\n      [ngClass]=\"btnClass\" [ngStyle]=\"itemStyles\" [href]=\"properties.href\">{{properties.label}}</a>\n    <ng-template #btn>\n      <button [ngClass]=\"btnClass\"\n        [type]=\"properties.type\" [ngStyle]=\"itemStyles\"\n        (click)=\"onClick()\">{{properties.label}}</button>\n    </ng-template>\n  "
        })
    ], ButtonUIComponent);
    return ButtonUIComponent;
}(BaseUIComponent));
var ButtonProperties = /** @class */ (function (_super) {
    __extends(ButtonProperties, _super);
    function ButtonProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Button label',
            example: 'Click me!',
        }),
        __metadata("design:type", String)
    ], ButtonProperties.prototype, "label", void 0);
    __decorate([
        propDescription({
            description: 'Key for action that fires onclick',
            example: 'submit',
        }),
        __metadata("design:type", String)
    ], ButtonProperties.prototype, "clickActionKey", void 0);
    __decorate([
        propDescription({
            description: 'Bootstrap predefined button class',
            example: 'btn-secondary',
        }),
        __metadata("design:type", String)
    ], ButtonProperties.prototype, "btnClass", void 0);
    __decorate([
        propDescription({
            description: 'Button type: button|submit|reset|link. Default: button',
            example: 'submit',
        }),
        __metadata("design:type", String)
    ], ButtonProperties.prototype, "type", void 0);
    __decorate([
        propDescription({
            description: 'Link href used in case of type=link.',
            example: 'submit',
        }),
        __metadata("design:type", String)
    ], ButtonProperties.prototype, "href", void 0);
    return ButtonProperties;
}(StyleProperties));
var example$7 = {
    title: 'Basic button example',
    uiModel: {
        type: packageName + ":button",
        containerProperties: {},
        itemProperties: {
            label: 'SUBMIT',
            width: '50%',
            margin: '15px',
            padding: '10px 5px 10px 0px',
            clickActionKey: 'consoleLog',
            type: 'button'
        }
    },
    dataModel: {}
};
var buttonDescriptor = {
    name: 'button',
    label: 'Button',
    packageName: packageName,
    category: "Basic" /* Basic */,
    description: 'Button component',
    itemProperties: ButtonProperties,
    component: ButtonUIComponent,
    example: example$7,
    defaultModel: {
        type: packageName + ":button",
        containerProperties: {},
        itemProperties: {
            label: 'Label',
            clickActionKey: 'consoleLog',
            btnClass: 'btn-primary',
            type: 'button'
        }
    },
    propertiesDescriptor: [
        ['type', { name: 'type', label: 'Type', category: PropertyCategories.Main,
                combo: [['button', 'submit', 'reset']]
            }],
        ['btnClass', { name: 'btnClass', label: 'CSS Class', category: PropertyCategories.Main,
                combo: [['btn-primary', 'btn-secondary', 'btn-light', 'btn-success', 'btn-danger',
                        'btn-warning', 'btn-info', 'btn-dark', 'btn-link']]
            }],
    ]
};

var CardComponent = /** @class */ (function (_super) {
    __extends(CardComponent, _super);
    function CardComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(CardComponent.prototype, "header", {
        get: function () {
            return this.getChildByIndex(0);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardComponent.prototype, "content", {
        get: function () {
            return this.getChildByIndex(1);
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CardComponent.prototype, "footer", {
        get: function () {
            return this.getChildByIndex(2);
        },
        enumerable: true,
        configurable: true
    });
    CardComponent.prototype.getChildByIndex = function (index) {
        return getItemByIndex(this.uiModel.children, index);
    };
    CardComponent = __decorate([
        Component({
            selector: 'dc-card',
            template: "\n  <div class=\"card\">\n    <div class=\"card-header\" *ngIf=\"header\">\n      <dc-ui-selector\n        (changedDataModel)=\"changedDataModel.emit(this.dataModel)\"\n        [uiModel]='header'\n        [dataModel]='dataModel'\n        [interpreter]='interpreter'\n        [scripts]='scripts'></dc-ui-selector>\n    </div>\n    <div class=\"card-body\" *ngIf=\"content\">\n      <dc-ui-selector\n        (changedDataModel)=\"changedDataModel.emit(this.dataModel)\"\n        [uiModel]='content'\n        [dataModel]='dataModel'\n        [interpreter]='interpreter'\n        [scripts]='scripts'></dc-ui-selector>\n    </div>\n    <div class=\"card-footer\" *ngIf=\"footer\">\n      <dc-ui-selector\n        (changedDataModel)=\"changedDataModel.emit(this.dataModel)\"\n        [uiModel]='footer'\n        [dataModel]='dataModel'\n        [interpreter]='interpreter'\n        [scripts]='scripts'></dc-ui-selector>\n    </div>\n  </div>"
        })
    ], CardComponent);
    return CardComponent;
}(BaseUIComponent));
var CardProperties = /** @class */ (function (_super) {
    __extends(CardProperties, _super);
    function CardProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Card can have 3 children, 1 - header, 2 - content, 3 - footer.',
            example: "[null, {\n      type: 'material:text',\n      containerProperties: {},\n      itemProperties: {\n        text: 'Card content text',\n      }\n    }, null]",
        }),
        __metadata("design:type", Array)
    ], CardProperties.prototype, "children", void 0);
    return CardProperties;
}(ContainerProperties));
var example$8 = {
    title: 'Card panel example',
    uiModel: {
        type: 'bootstrap:card',
        containerProperties: {},
        itemProperties: {
            padding: '10px',
            margin: '10px auto',
            width: '80%'
        },
        children: [{
                type: 'material:text',
                containerProperties: {},
                itemProperties: {
                    text: 'Card header text',
                    width: '100%'
                }
            }, {
                type: 'material:textarea',
                containerProperties: {
                    width: '100%',
                },
                itemProperties: {
                    rows: 4,
                    placeholder: 'Type card information',
                    dataModelPath: '$.card/info'
                }
            }, {
                type: 'bootstrap:button',
                containerProperties: {},
                itemProperties: {
                    label: 'Submit',
                    margin: '16px',
                    width: '50%',
                    clickActionKey: 'consoleLog'
                }
            }]
    },
    dataModel: {}
};
var cardDescriptor = {
    name: 'card',
    label: 'Card',
    packageName: packageName,
    category: "Containers" /* Containers */,
    description: 'Card layout component',
    itemProperties: CardProperties,
    component: CardComponent,
    example: example$8
};

var TextUIComponent = /** @class */ (function (_super) {
    __extends(TextUIComponent, _super);
    function TextUIComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.display = 'inline-block';
        return _this;
    }
    Object.defineProperty(TextUIComponent.prototype, "txtStyle", {
        get: function () {
            return this.properties['text-style'];
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextUIComponent.prototype, "text", {
        get: function () {
            return this.componentDataModel || this.properties.text;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        HostBinding('style.display'),
        __metadata("design:type", Object)
    ], TextUIComponent.prototype, "display", void 0);
    TextUIComponent = __decorate([
        Component({
            selector: 'dc-ui-text',
            template: "\n    <div [ngSwitch]=\"txtStyle\">\n      <h1 *ngSwitchCase=\"'h1'\" [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</h1>\n      <h2 *ngSwitchCase=\"'h2'\" [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</h2>\n      <h3 *ngSwitchCase=\"'h3'\" [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</h3>\n      <h4 *ngSwitchCase=\"'h4'\" [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</h4>\n      <h5 *ngSwitchCase=\"'h5'\" [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</h5>\n      <h6 *ngSwitchCase=\"'h6'\" [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</h6>\n      <p *ngSwitchCase=\"''\" [ngStyle]=\"itemStyles\">{{text}}</p>\n      <p *ngSwitchCase=\"undefined\" [ngStyle]=\"itemStyles\">{{text}}</p>\n      <span *ngSwitchDefault [class]=\"txtStyle\" [ngStyle]=\"itemStyles\">{{text}}</span>\n    </div>\n    "
        })
    ], TextUIComponent);
    return TextUIComponent;
}(BaseUIComponent));
var TextProperties = /** @class */ (function (_super) {
    __extends(TextProperties, _super);
    function TextProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Displays text data.',
            example: 'Text information',
        }),
        __metadata("design:type", String)
    ], TextProperties.prototype, "text", void 0);
    __decorate([
        propDescription({
            description: 'Text style text data.',
            example: 'h2',
        }),
        __metadata("design:type", String)
    ], TextProperties.prototype, "text-style", void 0);
    return TextProperties;
}(BindingProperties));
var example$9 = {
    title: 'Text compoent example',
    uiModel: {
        type: packageName + ":text",
        containerProperties: {},
        itemProperties: {
            text: "",
            width: '50%',
            padding: '20px'
        }
    },
    dataModel: {}
};
var textDescriptor = {
    name: 'text',
    packageName: packageName,
    label: 'Text',
    category: "Basic" /* Basic */,
    description: 'Text component',
    itemProperties: TextProperties,
    component: TextUIComponent,
    example: example$9,
    defaultModel: {
        type: packageName + ":text",
        itemProperties: {
            text: 'Text',
            width: '100%'
        },
        containerProperties: {}
    },
    propertiesDescriptor: [
        ['text-style', {
                name: 'text-style', label: 'Text style', category: PropertyCategories.Main,
                combo: [['h1', 'h2', 'h3', 'h4', 'h5', 'h6', 'display-1', 'display-2', 'display-3', 'display-4']]
            }]
    ]
};

var IconUIComponent = /** @class */ (function (_super) {
    __extends(IconUIComponent, _super);
    function IconUIComponent() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.display = 'inline-block';
        return _this;
    }
    Object.defineProperty(IconUIComponent.prototype, "iconClass", {
        get: function () {
            return this.componentDataModel || this.properties.iconClass;
        },
        enumerable: true,
        configurable: true
    });
    __decorate([
        HostBinding('style.display'),
        __metadata("design:type", Object)
    ], IconUIComponent.prototype, "display", void 0);
    IconUIComponent = __decorate([
        Component({
            selector: 'dc-icon-ui',
            template: "\n    <div [ngSwitch]=\"itemStyles\">\n      <i [class]=\"iconClass\" [ngStyle]=\"{fontSize: properties.size || '1rem'}\"></i>\n    </div>\n    ",
            styles: ['./icon-ui.component.sass']
        })
    ], IconUIComponent);
    return IconUIComponent;
}(BaseUIComponent));
var IconProperties = /** @class */ (function (_super) {
    __extends(IconProperties, _super);
    function IconProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    __decorate([
        propDescription({
            description: 'Icon font awesome class',
            example: 'Text information',
        }),
        __metadata("design:type", String)
    ], IconProperties.prototype, "iconClass", void 0);
    __decorate([
        propDescription({
            description: 'Icon size',
            example: '2rem',
        }),
        __metadata("design:type", String)
    ], IconProperties.prototype, "size", void 0);
    return IconProperties;
}(BindingProperties));
var example$a = {
    title: 'Icon compoent example',
    uiModel: {
        type: packageName + ":icon",
        containerProperties: {},
        itemProperties: {
            iconClass: 'fa fa-play',
            width: '50%',
            padding: '20px'
        }
    },
    dataModel: {}
};
var ICONS = ['fa fa-send', 'fa fa-play', 'fa fa-picture-o', 'fa fa-area-chart', 'fa fa-bank', 'fa fa-beer',
    'fa fa-automobile', 'fa fa-bag', 'fa fa-book', 'fa fa-bell', 'fa fa-camera', 'fa fa-calendar', 'fa fa-user',
    'fa fa-globe', 'fa fa-gift', 'fa fa-group', 'fa fa-gear', 'fa fa-info', 'fa fa-money', 'fa fa-print', 'fa fa-registered',
    'fa fa-share', 'fa fa-shopping-card', 'fa fa-tags', 'fa fa-tasks', 'fa fa-star', 'fa fa-univarsity', 'fa fa-file', 'fa fa-ticket',
    'fa fa-television', 'fa fa-suitcase', 'fa fa-server', 'fa fa-map', 'fa fa-leptop', 'fa fa-home', 'fa fa-hashtag', 'fa fa-clock-o'];
var iconDescriptor = {
    name: 'icon',
    packageName: packageName,
    label: 'Icon',
    category: "Basic" /* Basic */,
    description: 'Icon component',
    itemProperties: IconProperties,
    component: IconUIComponent,
    example: example$a,
    defaultModel: {
        type: packageName + ":icon",
        itemProperties: {
            iconClass: 'fa fa-play',
            width: '100%'
        },
        containerProperties: {}
    },
    propertiesDescriptor: [
        ['iconClass', {
                name: 'iconClass', label: 'Icon Class', category: PropertyCategories.Main,
                combo: [ICONS]
            }]
    ]
};

var TabsUIComponent = /** @class */ (function (_super) {
    __extends(TabsUIComponent, _super);
    function TabsUIComponent() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TabsUIComponent = __decorate([
        Component({
            selector: 'dc-tabs-ui',
            template: "\n    <tabset drop-container class=\"tabset-fx\">\n      <tab *ngFor=\"let item of uiModel.children; let i = index\" [heading]=\"item.containerProperties.label || 'Tab ' + (i + 1)\">\n      <dc-ui-selector\n          (changedDataModel)=\"changedDataModel.emit(dataModel)\"\n          [uiModel]='item'\n          [dataModel]='dataModel'\n          [interpreter]='interpreter'\n          [scripts]='scripts'></dc-ui-selector>\n      </tab>\n    </tabset>\n  "
        })
    ], TabsUIComponent);
    return TabsUIComponent;
}(BaseUIComponent));
var TabsProperties = /** @class */ (function (_super) {
    __extends(TabsProperties, _super);
    function TabsProperties() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return TabsProperties;
}(StyleProperties));
var example$b = {
    title: 'Tabs group example',
    uiModel: {
        type: 'bootstrap:tabs',
        containerProperties: {},
        itemProperties: {},
        children: [{
                type: 'material:text-input',
                containerProperties: {
                    width: '100%',
                    label: 'Input tab',
                },
                itemProperties: {
                    isNumeric: false,
                    isDate: false,
                    format: '',
                    placeholder: 'Inout text component',
                    dataModelPath: '$.tabOne/inputValue'
                }
            }, {
                type: 'material:text',
                containerProperties: {
                    label: 'Text tab',
                },
                itemProperties: {
                    text: 'Text information',
                }
            }, {
                type: 'material:select',
                containerProperties: {
                    label: 'Country select',
                },
                itemProperties: {
                    options: [
                        { label: 'United Kingdom', value: 'uk' },
                        { label: 'Ukraine', value: 'ua' }
                    ],
                    placeholder: 'Country',
                    dataModelPath: '$.country'
                }
            }]
    },
    dataModel: {}
};
var tabsDescriptor = {
    name: 'tabs',
    label: 'Tabs container (Bootstrap)',
    packageName: packageName,
    category: "Containers" /* Containers */,
    description: 'Tabs component',
    itemProperties: TabsProperties,
    component: TabsUIComponent,
    example: example$b,
    defaultModel: {
        type: 'bootstrap:tabs',
        containerProperties: {},
        itemProperties: {},
        children: [{
                type: 'material:flex-container',
                containerProperties: {
                    width: '100%',
                    height: '100%',
                    label: 'Tab 1',
                },
                itemProperties: {
                    children: [],
                    width: '100%',
                    height: '100%',
                }
            }, {
                type: 'material:flex-container',
                containerProperties: {
                    width: '100%',
                    height: '100%',
                    label: 'Tab 2',
                },
                itemProperties: {
                    children: [],
                    width: '100%',
                    height: '100%',
                }
            }]
    }
};

var COMPONENTS_LIST = [
    containerDescriptor,
    containerRowDescriptor,
    inputDescriptor,
    selectDescriptor,
    checkboxDescriptor,
    radioGroupDescriptor,
    textareaDescriptor,
    buttonDescriptor,
    cardDescriptor,
    textDescriptor,
    iconDescriptor,
    tabsDescriptor
];
// Register components.
function registerComponents() {
    COMPONENTS_LIST.forEach(function (component) { return CoreService.registerComponent(component); });
}
function getCategories() {
    var categories = COMPONENTS_LIST.reduce(function (map, desc) {
        map[desc.category] = map[desc.category] || [];
        map[desc.category].push(desc);
        return map;
    }, {});
    return Object.entries(categories).map(function (_a) {
        var _b = __read(_a, 2), key = _b[0], val = _b[1];
        return {
            name: key,
            components: val,
            packageName: packageName
        };
    });
}

var BootstrapModule = /** @class */ (function () {
    function BootstrapModule() {
        setTheme('bs4');
        registerComponents();
    }
    BootstrapModule = __decorate([
        NgModule({
            declarations: [ContainerComponent, ContainerRowComponent, InputUIComponent, SelectUIComponent,
                CheckboxUIComponent, RadioGroupUIComponent, TextareaUIComponent, ButtonUIComponent, CardComponent,
                TextUIComponent, IconUIComponent, TabsUIComponent],
            imports: [
                CoreModule,
                CommonModule,
                FormsModule,
                FlexLayoutModule,
                NgSelectModule,
                TabsModule.forRoot()
            ],
            exports: [ContainerComponent, ContainerRowComponent, InputUIComponent]
        }),
        __metadata("design:paramtypes", [])
    ], BootstrapModule);
    return BootstrapModule;
}());

/*
 * Public API Surface of bootstrap
 */

/**
 * Generated bundle index. Do not edit.
 */

export { BootstrapModule, ButtonUIComponent, COMPONENTS_LIST, CardComponent, CheckboxUIComponent, ContainerComponent, ContainerRowComponent, IconUIComponent, InputUIComponent, RadioGroupUIComponent, SelectUIComponent, TabsUIComponent, TextUIComponent, TextareaUIComponent, getCategories, ContainerComponent as ɵa, BSContainerProperties as ɵb, example$6 as ɵba, textareaDescriptor as ɵbb, ButtonUIComponent as ɵbc, ButtonProperties as ɵbd, example$7 as ɵbe, buttonDescriptor as ɵbf, CardComponent as ɵbg, CardProperties as ɵbh, cardDescriptor as ɵbi, TextUIComponent as ɵbj, TextProperties as ɵbk, textDescriptor as ɵbl, IconUIComponent as ɵbm, IconProperties as ɵbn, iconDescriptor as ɵbo, TabsUIComponent as ɵbp, TabsProperties as ɵbq, example$b as ɵbr, tabsDescriptor as ɵbs, packageName as ɵbt, example as ɵc, containerDescriptor as ɵd, ContainerRowComponent as ɵe, BSContainerRowProperties as ɵf, example$1 as ɵg, containerRowDescriptor as ɵh, InputUIComponent as ɵi, InputProperties as ɵj, example$2 as ɵk, inputDescriptor as ɵl, SelectUIComponent as ɵm, SelectProperties as ɵn, example$3 as ɵo, selectDescriptor as ɵp, CheckboxUIComponent as ɵq, CheckboxProperties as ɵr, example$4 as ɵs, checkboxDescriptor as ɵt, RadioGroupUIComponent as ɵu, RadioGroupProperties as ɵv, example$5 as ɵw, radioGroupDescriptor as ɵx, TextareaUIComponent as ɵy, TextareaProperties as ɵz };
//# sourceMappingURL=ngx-dynamic-components-bootstrap.js.map
